@@ -408,7 +408,6 @@ class Socket_Server_Client:
             self.socket.close()
         except:
             pass
-        
 
     def send(self, data):
         """
@@ -453,11 +452,13 @@ class Socket_Server_Client:
         tok = essentials.CreateToken(20, self.__ask_list__)
         self.__ask_list__[tok] = False
         self.send({"function_ask_question": tok, "data": data})
-        while self.__ask_list__[tok] == False:
+        while self.__ask_list__[tok] == False and self.running == True:
             time.sleep(0.01)
             timeout -= 0.01
             if timeout <= 0:
                 raise TimeoutError("No response within time.")
+        if self.__ask_list__[tok] == False and self.running == False:
+            raise ConnectionError("We've been disconnected while waiting for a response")
         copyed = copy.deepcopy(self.__ask_list__[tok])
         del self.__ask_list__[tok]
         return copyed['data']
@@ -469,7 +470,6 @@ class Socket_Server_Client:
             time.sleep(0.05)
         return self.get_next_data
 
-
     def __data_rev__(self):
         """
         Server background task for accepting data and run the on_data event, you'll not need to use this.
@@ -559,7 +559,6 @@ class Socket_Question(object):
     def answer(self, data):
         self.questioner.send({"function_ask_response": self.__answer_token__, "data": data})
 
-
 class Configuration(object):
 
     def __init__(self, default=PYTHONIC, on_data_recv=None, on_question=None, on_connection_close=None):
@@ -606,7 +605,6 @@ class Configuration(object):
         else:
             raise ValueError("Setting value must be True")
 
-
 class Socket_Connector:
 
     def __init__(self, HOST, PORT, Config=Configuration(PYTHONIC)):
@@ -628,7 +626,7 @@ class Socket_Connector:
         on_data_recv (:obj:`def`): Holds the function you specified to use, can be over written.
 
         """
-        self.running = True
+        self.running = False
         self.HOST = HOST
         self.PORT = PORT
         self.recv_data = b""
@@ -654,6 +652,7 @@ class Socket_Connector:
         if self.configuration.WEBONIC:
             raise NotImplementedError("Websocket Clients Haven't been Implemented Yet.")
         self.socket = ConnectorSocket(self.HOST, self.PORT, timeout)
+        self.running = True
         if self.configuration.PYTHONIC == True:
             self.send({"pythonic": True})
             if self.configuration.server_PYTHONIC_only == False:
@@ -682,11 +681,13 @@ class Socket_Connector:
         tok = essentials.CreateToken(20, self.__ask_list__)
         self.__ask_list__[tok] = False
         self.send({"function_ask_question": tok, "data": data})
-        while self.__ask_list__[tok] == False:
+        while self.__ask_list__[tok] == False and self.running == True:
             time.sleep(0.01)
             timeout -= 0.01
             if timeout <= 0:
                 raise TimeoutError("No response within time.")
+        if self.__ask_list__[tok] == False and self.running == False:
+            raise ConnectionError("We've been disconnected while waiting for a response")
         copyed = copy.deepcopy(self.__ask_list__[tok])
         del self.__ask_list__[tok]
         return copyed['data']
@@ -872,7 +873,6 @@ class UDP_Server(object):
         except:
             pass
 
-
 class UDP_Connector(object):
 
     def __init__(self, HOST, PORT, on_data=None, timeout=1, max_buffer=1024):
